@@ -6,7 +6,7 @@ Toadfarm - One Mojolicious app to rule them all
 
 =head1 VERSION
 
-0.51
+0.52
 
 =head1 DESCRIPTION
 
@@ -33,7 +33,7 @@ This feature is very much like L<Mojolicious::Plugin::Mount> on steroids.
 =item *
 
 Hijacking log messages to a common log file. There's also plugin,
-L<Toadfarm::Plugin::AccessLog>, that allow you to log the requests sent
+L<Toadfarm::Plugin::AccessLog>, that allows you to log the requests sent
 to your server.
 
 =back
@@ -42,13 +42,13 @@ to your server.
 
 =head2 Script
 
-Here is an example script that set up logging and mount some applications
+Here is an example script that sets up logging and mounts some applications
 under different domains, as well as loading in some custom plugins.
 
 See L<Toadfarm::Manual::DSL> for more information about the different functions.
 
   #!/usr/bin/perl
-  use Toadfarm -dsl;
+  use Toadfarm -init;
 
   logging {
     combined => 1,
@@ -62,7 +62,7 @@ See L<Toadfarm::Manual::DSL> for more information about the different functions.
 
   plugin "Toadfarm::Plugin::AccessLog";
 
-  start; # need to be at the last line
+  start; # needs to be at the last line
 
 =head2 Usage
 
@@ -116,7 +116,7 @@ use File::Spec;
 use File::Which;
 use constant DEBUG => $ENV{TOADFARM_DEBUG} ? 1 : 0;
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 BEGIN {
   $ENV{TOADFARM_ACTION} //= $ENV{MOJO_APP_LOADER} ? 'load' : (@ARGV and $ARGV[0] =~ /^(reload|start|stop)$/) ? $1 : '';
@@ -124,7 +124,7 @@ BEGIN {
 }
 
 sub import {
-  return unless grep {/^-dsl/} @_;
+  return unless grep {/^(-dsl|-init)/} @_;
 
   my $class  = shift;
   my $caller = caller;
